@@ -1,5 +1,5 @@
 package Starch::Store::Amazon::DynamoDB;
-$Starch::Store::Amazon::DynamoDB::VERSION = '0.03';
+$Starch::Store::Amazon::DynamoDB::VERSION = '0.04';
 =head1 NAME
 
 Starch::Store::Amazon::DynamoDB - Starch storage backend using Amazon::DynamoDB.
@@ -94,7 +94,7 @@ with qw(
     Starch::Store
 );
 
-sub BUILD {
+after BUILD => sub{
     my ($self) = @_;
 
     # Get this loaded as early as possible.
@@ -107,7 +107,7 @@ sub BUILD {
     }
 
     return;
-}
+};
 
 =head1 REQUIRED ARGUMENTS
 
